'use strict';

const cors = require('@koa/cors');
const Koa = require('koa');
const bodyParser = require('koa-bodyparser');
const gin = require('koa-gin');
const Router = require('koa-router');
const serve = require('koa-static');

module.exports = class Server {
    constructor(options = {}, logger = console) {
        if (typeof options === 'number') options = { port: options };
        this.logger = logger;
        this.port = options.port || 8080;
        this.routes = options.routes || {};
        this.app = new Koa();
        this.router = new Router();
        this.gin = gin(logger);
        this.cors = cors(options.cors);
        this.serve = serve(options.serve || './dist');
        this.bodyParser = bodyParser(options.bodyParser || { jsonLimit: '50mb', formLimit: '50mb' });
    }

    run() {
        this.app
            .use(this.gin)
            .use(this.cors)
            .use(this.serve)
            .use(this.bodyParser)
            .use(this.router.routes())
            .use(this.router.allowedMethods())
            .listen(this.port, () => {
                this.logger.info('Server running at: http://0.0.0.0:%s', this.port);
            });
    }

    bind(route, binder, wrapper) {
        const [methodName, routeName] = route.split(' ');
        const method = methodName.toLowerCase();
        const path = this.routes[routeName] || routeName;
        this.router[method](path, wrapper ?
            wrapper(method, routeName, binder) : binder);
        return this;
    }

    attach(routes = {}, wrapper) {
        Object.entries(routes).forEach(([v, k]) => this.bind(v, k, wrapper));
        return this;
    }
};
